This function calculates the Cumulative density function (CDF) of the NTLKwIEx distribution.
C_NTLKwIEx(x, teta, alpha, a, b, m)Value of the CDF for the NTLKwIEx distribution evaluated at x
Value up to which to calculate the CDF.
Parameter teta of the distribution representing the distribution of the inverse exponential component.
Parameter alpha of the distribution representing the distribution of the new proposal component.
Parameter a of the distribution representing the distribution of the Kumaraswamy component.
Parameter b of the distribution representing the distribution of the Kumaraswamy component.
Parameter m of the distribution representing the distribution of the Topp Leone component.
It takes parameters x, teta, alpha, a, b, and m, and returns the CDF value at x based on these parameters. The formula used for the calculation is provided in the documentation header. The Cumulative Distribution Function (CDF) of the NTLKwIEx distribution is defined as: $$ F(x;a,b,m,\alpha,\theta) = \left[ 1-\left(1-K(x,\xi)^{a \alpha^{K(x,\xi)}}\right)^{2b} \right]^{m} $$ where \(\alpha , a , b, m, \theta > 0\).