This function generates a plot of the Cumulative Distribution Function (CDF) of the NTLKwIEx distribution over a specified range of x values.
Plot_CNTLKwIEx(teta, alpha, a, b, m, min_x, max_x)A plot of the CDF of the NTLKwIEx distribution
Parameter teta of the distribution
Parameter alpha of the distribution
Parameter a of the distribution
Parameter b of the distribution
Parameter m of the distribution
Minimum value of x for the plot
Maximum value of x for the plot