This function generates a graph of the probability density function (PDF) of the NTLKwIEx distribution over a specified range of x values.
Plot_PNTLKwIEx(teta, alpha, a, b, m, min_x, max_x)A graph of the PDF of the NTLKwIEx distribution
Parameter teta of the distribution
Parameter alpha of the distribution
Parameter a of the distribution
Parameter b of the distribution
Parameter m of the distribution
Minimum value of x for the graph
Maximum value of x for the graph