This function calculates the quantile value of the NTLKwIEx distribution for a given probability p.
Q_NTLKwIEx(p, teta, alpha, a, b, m)The quantile value corresponding to the probability p for the NTLKwIEx distribution
Probability for which the quantile value is to be calculated (0 <= p <= 1)
Parameter teta of the distribution
Parameter alpha of the distribution
Parameter a of the distribution
Parameter b of the distribution
Parameter m of the distribution